#ifndef _TRAY_H
#define _TRAY_H

#include <stdio.h>
#include <stdlib.h>

#include "TrayMapUnit.h"

typedef enum {OBSTACLE, MOUNTAIN, EARTH, SWAMP, WATER, NORMAL}Ground;
typedef enum {SELECT, MOVE, PAUSE, NO_UNIT} StateUnit;
typedef enum {BEGIN_POSITION, NOTHING, END_POSITION}Target;

typedef struct
{
	int	way;
	double	cost;
	double	cumul_cost;
	Ground	ground;
	StateUnit	state_unit;
	Target	target;
}Rectangle;


typedef struct
{
	int column;
	int row;
}CurrentPosition;

typedef CurrentPosition PathResult[40];

typedef struct
{
	int columns;
	int rows;
	int lengthOfWay;
	ArrayMapCumulCost arrayMapCumulCost;
	Rectangle **rectangle;
	PathResult pathResult;
}Tray;

/* Respect step in order :
 * - Create object with new_tray
 * - Initialize cost ground with Tray_set_cost() [else cost ground is init by default in constructor]
 * example :
 * CostGround cost_ground;
	cost_ground.obstacle = 0;
	cost_ground.earth = 1;
	cost_ground.mountain = 2;
	cost_ground.swamp = 2;
	cost_ground.water = 0;
	cost_ground.total_cost = 10;
 * - you must to call Tray_calcul_cost_starting_position()
 * and after Tray_calcul_cost_arrival_position()
 * ArrayMap and CostGround structure is defined in TrayMapUnit.h
*/
Tray *new_tray(ArrayMapASCII array_map_ascii, int columns, int rows);
void Tray_calcul_cost_starting_position(Tray *tray, int column, int row);
int Tray_calcul_cost_arrival_position(Tray *tray, int column, int row);
void Tray_display_ground(Tray *tray);
void Tray_display_cost_ground(Tray *tray);
void Tray_display_cumul_cost(Tray *tray);
void Tray_reset(Tray *tray);
void Tray_set_cost(Tray *tray, CostGround costGround);
void free_tray(Tray *tray);
#endif
